@@ -57,8 +57,6 @@ typedef struct _LogWriterOptions
   /* minimum number of entries to trigger a flush */
   gint flush_lines;
 
-  /* flush anyway if this time was elapsed */
-  gint flush_timeout;
   LogTemplate *template;
   LogTemplate *file_template;
   LogTemplate *proto_template;
@@ -89,12 +87,13 @@ void log_writer_reopen(LogWriter *self, LogProtoClient *proto);
 void log_writer_set_queue(LogWriter *self, LogQueue *queue);
 LogQueue *log_writer_get_queue(LogWriter *s);
 LogWriter *log_writer_new(guint32 flags, GlobalConfig *cfg);
+void log_writer_msg_rewind(LogWriter *self);
 
 void log_writer_options_set_template_escape(LogWriterOptions *options, gboolean enable);
 void log_writer_options_defaults(LogWriterOptions *options);
 void log_writer_options_init(LogWriterOptions *options, GlobalConfig *cfg, guint32 option_flags);
 void log_writer_options_destroy(LogWriterOptions *options);
-void log_writer_options_set_mark_mode(LogWriterOptions *options, gchar *mark_mode);
+void log_writer_options_set_mark_mode(LogWriterOptions *options, const gchar *mark_mode);
 gint log_writer_options_lookup_flag(const gchar *flag);
 
 #endif
